@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2022 jvherck (https://jvherck.github.io/dicebear/)
+# Copyright (c) 2023 jvherck (on GitHub)
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -19,19 +19,23 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
+import typing
 
 import requests as r
-from urllib.parse import quote
-from string import ascii_lowercase, digits
-
 import os
 import pathlib
 import io
+from urllib.parse import quote
+from string import ascii_lowercase, digits
 from ast import literal_eval
+from typing import Union
+from random import choices
 
 from .models import *
 from .errors import *
-from .models import _FindPil
+from .models import _FindPil, pilcheck
+
+__all__ = ('DAvatar',)
 
 try:
     from PIL import Image as i
@@ -42,7 +46,7 @@ except Exception:
     _FindPil.found = False
 
 
-_x = "https://api.dicebear.com/5.1/{}/svg?seed={}&"
+_x = "https://api.dicebear.com/5.3/{}/svg?seed={}&"
 
 
 class DAvatar:
@@ -53,8 +57,7 @@ class DAvatar:
     all_options: list = options
     def __init__(self, style: DStyle = None, seed: str = None, *, options: DOptions = None, custom: dict = None) -> None:
         """
-        Create an avatar using this class, use `.url_svg` to get the svg url or `.url_png` to get the png url.
-        Clickable links: https://github.com/jvherck/dicebear#styles , https://github.com/jvherck/dicebear#base-options , https://github.com/jvherck/dicebear#specific-style-options
+        Create a new avatar object.
 
         :param style: class `dicebear.models.DStyle` :: the style of avatar you want to create; check the whole list at https://github.com/jvherck/dicebear#styles
         :type style: dicebear.models.DStyle
@@ -138,7 +141,7 @@ class DAvatar:
     @property
     def text(self) -> str:
         """
-        :return: returns the bytes of the avatar in str format
+        :return: returns the avatar's request's full text/file in str format
         """
         return self.__text
     @property
@@ -158,7 +161,11 @@ class DAvatar:
     def __ge__(self, other): return self.options["size"] >= other.options["size"]
     def __gt__(self, other): return self.options["size"] > other.options["size"]
     def __dict__(self): return {"style": self.style, "seed": self.seed, "options": self.options, "custom": self.customisations}
-    def __contains__(self, item): return item in self.options or item in self.customisations
+    def __contains__(self, key: str):
+        """
+        Returns `True` if the specified key is found in either DAvatar.options.keys() or DAvatar.customisations.keys(), else returns `False`
+        """
+        return key in self.options.keys() or key in self.customisations.keys()
 
 
 
@@ -170,13 +177,12 @@ class DAvatar:
                 _options.append("{}={}".format(quote(item), quote(str(self.__options[item]).replace("False", "false").replace("True", "true"))))
         for item in self.__specific:
             _specoptions.append("{}={}".format(quote(item), quote(str(self.__specific[item]).replace("False", "false").replace("True", "true"))))
-        _link += "&".join(_options) + "&" + "&".join(_specoptions)
+        _link += "&".join(_options+_specoptions)
         _link = _link.format(quote(str(self.__style)), quote(self.__seed))
         req = r.get(_link)
         try: status = literal_eval(req.text)
         except (ValueError, SyntaxError): pass
         if type(status) == dict and "statusCode" in status: raise HTTPError(status)
-
         self.__url_svg = req.url
         self.__text, self.__content = req.text, req.content
         self.__bytes = io.BytesIO(req.content)
@@ -227,7 +233,7 @@ class DAvatar:
         self.__update()
         return self.__url_svg
 
-    customize = edit_specific = customise
+    customize: callable = customise
 
     def save(self, *,
              location: Union[pathlib.Path, str] = None,
@@ -303,7 +309,7 @@ class DAvatar:
             log_error(ModuleNotFoundError("Module `Pillow` is not found or installed"), True)
         else: os.startfile(self.__getattribute__("url_"+str(format)), "open")
 
-    open = view
+    open: callable = view
 
     @pilcheck
     def __view_pil(self) -> None: self.pillow().show()
