@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2022 jvherck (https://jvherck.github.io/dicebear/)
+# Copyright (c) 2023 jvherck (on GitHub)
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -22,6 +22,18 @@
 from typing import Union
 import logging
 
+__all__ = (
+    'IncorrectColor',
+    'InvalidOption',
+    'Error',
+    'HTTPError',
+    'ImageError',
+    'ImageValueError',
+    'ImageOSError',
+    'PILError',
+    'log_error',
+)
+
 class IncorrectColor(Exception):
     """Incorrect color"""
     def __init__(self, wrong_color: str = None):
