@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2022 jvherck (https://jvherck.github.io/dicebear/)
+# Copyright (c) 2023 jvherck (on GitHub)
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -20,13 +20,23 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from . import DFormat, DStyle, DOptions, DAvatar
+from . import DStyle, DOptions, DAvatar
 from string import ascii_lowercase, digits
 from random import choices
-import typing
+from typing import Union, List, Annotated
+
+__all__ = (
+    'create_avatar',
+    'bulk_create',
+)
 
 
-def create_avatar(style: DStyle, seed: str, options: typing.Union[DOptions, None] = None, customisations: typing.Union[dict, None] = None) -> DAvatar:
+def create_avatar(
+        style: DStyle,
+        seed: str,
+        options: Union[DOptions, None] = None,
+        customisations: Union[dict, None] = None
+) -> DAvatar:
     """
     Creates a DAvatar object and returns it.
 
@@ -39,7 +49,13 @@ def create_avatar(style: DStyle, seed: str, options: typing.Union[DOptions, None
     return DAvatar(style, seed, options=options, custom=customisations)
 
 
-def bulk_create(style: DStyle = DStyle.random(), amount: typing.Annotated[int, "Min: 1, Max: 50"] = 2, *, options: DOptions = None, custom: dict = None) -> typing.List[DAvatar]:
+def bulk_create(
+        style: DStyle = DStyle.random(),
+        amount: Annotated[int, "Min: 1, Max: 50"] = 2,
+        *,
+        options: DOptions = None,
+        custom: dict = None
+) -> List[DAvatar]:
     """
     Creates a list of :py:class:`DAvatar` objects. Easy way to make multiple of the same style (but different randomly generated seeds) at once.
 
